==> allure-report-data-1.3.6-sources.jar: ru/yandex/qatools/allure/data/ObjectFactory.java <==

package ru.yandex.qatools.allure.data;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.yandex.qatools.allure.data package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AllureTestSuite_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-suite");
    private final static QName _AllureTestCase_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-case");
    private final static QName _AllureTestCasePack_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-case-pack");
    private final static QName _AllureDefects_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-defects");
    private final static QName _AllureTestRun_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-run");
    private final static QName _ListFiles_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "list-files");
    private final static QName _AllureXUnit_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-x-unit");
    private final static QName _AllureGraph_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-graph");
    private final static QName _AllureBehavior_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-behavior");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.yandex.qatools.allure.data
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AllureBehavior }
     * 
     */
    public AllureBehavior createAllureBehavior() {
        return new AllureBehavior();
    }

    /**
     * Create an instance of {@link AllureGraph }
     * 
     */
    public AllureGraph createAllureGraph() {
        return new AllureGraph();
    }

    /**
     * Create an instance of {@link AllureXUnit }
     * 
     */
    public AllureXUnit createAllureXUnit() {
        return new AllureXUnit();
    }

    /**
     * Create an instance of {@link ListFiles }
     * 
     */
    public ListFiles createListFiles() {
        return new ListFiles();
    }

    /**
     * Create an instance of {@link AllureTestRun }
     * 
     */
    public AllureTestRun createAllureTestRun() {
        return new AllureTestRun();
    }

    /**
     * Create an instance of {@link AllureDefects }
     * 
     */
    public AllureDefects createAllureDefects() {
        return new AllureDefects();
    }

    /**
     * Create an instance of {@link AllureTestCasePack }
     * 
     */
    public AllureTestCasePack createAllureTestCasePack() {
        return new AllureTestCasePack();
    }

    /**
     * Create an instance of {@link AllureTestCase }
     * 
     */
    public AllureTestCase createAllureTestCase() {
        return new AllureTestCase();
    }

    /**
     * Create an instance of {@link AllureTestSuite }
     * 
     */
    public AllureTestSuite createAllureTestSuite() {
        return new AllureTestSuite();
    }

    /**
     * Create an instance of {@link Summary }
     * 
     */
    public Summary createSummary() {
        return new Summary();
    }

    /**
     * Create an instance of {@link DefectItem }
     * 
     */
    public DefectItem createDefectItem() {
        return new DefectItem();
    }

    /**
     * Create an instance of {@link Time }
     * 
     */
    public Time createTime() {
        return new Time();
    }

    /**
     * Create an instance of {@link AllureTestCaseInfo }
     * 
     */
    public AllureTestCaseInfo createAllureTestCaseInfo() {
        return new AllureTestCaseInfo();
    }

    /**
     * Create an instance of {@link AllureStep }
     * 
     */
    public AllureStep createAllureStep() {
        return new AllureStep();
    }

    /**
     * Create an instance of {@link AllureDefect }
     * 
     */
    public AllureDefect createAllureDefect() {
        return new AllureDefect();
    }

    /**
     * Create an instance of {@link Statistic }
     * 
     */
    public Statistic createStatistic() {
        return new Statistic();
    }

    /**
     * Create an instance of {@link AllureStory }
     * 
     */
    public AllureStory createAllureStory() {
        return new AllureStory();
    }

    /**
     * Create an instance of {@link AllureFeature }
     * 
     */
    public AllureFeature createAllureFeature() {
        return new AllureFeature();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestSuite }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-suite")
    public JAXBElement<AllureTestSuite> createAllureTestSuite(AllureTestSuite value) {
        return new JAXBElement<AllureTestSuite>(_AllureTestSuite_QNAME, AllureTestSuite.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestCase }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-case")
    public JAXBElement<AllureTestCase> createAllureTestCase(AllureTestCase value) {
        return new JAXBElement<AllureTestCase>(_AllureTestCase_QNAME, AllureTestCase.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestCasePack }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-case-pack")
    public JAXBElement<AllureTestCasePack> createAllureTestCasePack(AllureTestCasePack value) {
        return new JAXBElement<AllureTestCasePack>(_AllureTestCasePack_QNAME, AllureTestCasePack.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureDefects }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-defects")
    public JAXBElement<AllureDefects> createAllureDefects(AllureDefects value) {
        return new JAXBElement<AllureDefects>(_AllureDefects_QNAME, AllureDefects.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestRun }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-run")
    public JAXBElement<AllureTestRun> createAllureTestRun(AllureTestRun value) {
        return new JAXBElement<AllureTestRun>(_AllureTestRun_QNAME, AllureTestRun.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ListFiles }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "list-files")
    public JAXBElement<ListFiles> createListFiles(ListFiles value) {
        return new JAXBElement<ListFiles>(_ListFiles_QNAME, ListFiles.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureXUnit }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-x-unit")
    public JAXBElement<AllureXUnit> createAllureXUnit(AllureXUnit value) {
        return new JAXBElement<AllureXUnit>(_AllureXUnit_QNAME, AllureXUnit.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureGraph }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-graph")
    public JAXBElement<AllureGraph> createAllureGraph(AllureGraph value) {
        return new JAXBElement<AllureGraph>(_AllureGraph_QNAME, AllureGraph.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureBehavior }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-behavior")
    public JAXBElement<AllureBehavior> createAllureBehavior(AllureBehavior value) {
        return new JAXBElement<AllureBehavior>(_AllureBehavior_QNAME, AllureBehavior.class, null, value);
    }

}

==> allure-report-data-1.4.7-sources.jar: ru/yandex/qatools/allure/data/ObjectFactory.java <==

package ru.yandex.qatools.allure.data;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.yandex.qatools.allure.data package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AllureTestSuite_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-suite");
    private final static QName _AllureTestCase_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-case");
    private final static QName _AllureTestCasePack_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-case-pack");
    private final static QName _AllureDefects_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-defects");
    private final static QName _AllureTestRun_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-test-run");
    private final static QName _AllureTimeline_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-timeline");
    private final static QName _ListFiles_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "list-files");
    private final static QName _AllureXUnit_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-x-unit");
    private final static QName _AllureGraph_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-graph");
    private final static QName _AllureBehavior_QNAME = new QName("urn:data.allure.qatools.yandex.ru", "allure-behavior");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.yandex.qatools.allure.data
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AllureBehavior }
     * 
     */
    public AllureBehavior createAllureBehavior() {
        return new AllureBehavior();
    }

    /**
     * Create an instance of {@link AllureGraph }
     * 
     */
    public AllureGraph createAllureGraph() {
        return new AllureGraph();
    }

    /**
     * Create an instance of {@link AllureXUnit }
     * 
     */
    public AllureXUnit createAllureXUnit() {
        return new AllureXUnit();
    }

    /**
     * Create an instance of {@link ListFiles }
     * 
     */
    public ListFiles createListFiles() {
        return new ListFiles();
    }

    /**
     * Create an instance of {@link AllureTimeline }
     * 
     */
    public AllureTimeline createAllureTimeline() {
        return new AllureTimeline();
    }

    /**
     * Create an instance of {@link AllureTestRun }
     * 
     */
    public AllureTestRun createAllureTestRun() {
        return new AllureTestRun();
    }

    /**
     * Create an instance of {@link AllureDefects }
     * 
     */
    public AllureDefects createAllureDefects() {
        return new AllureDefects();
    }

    /**
     * Create an instance of {@link AllureTestCasePack }
     * 
     */
    public AllureTestCasePack createAllureTestCasePack() {
        return new AllureTestCasePack();
    }

    /**
     * Create an instance of {@link AllureTestCase }
     * 
     */
    public AllureTestCase createAllureTestCase() {
        return new AllureTestCase();
    }

    /**
     * Create an instance of {@link AllureTestSuite }
     * 
     */
    public AllureTestSuite createAllureTestSuite() {
        return new AllureTestSuite();
    }

    /**
     * Create an instance of {@link Summary }
     * 
     */
    public Summary createSummary() {
        return new Summary();
    }

    /**
     * Create an instance of {@link AllureAttachment }
     * 
     */
    public AllureAttachment createAllureAttachment() {
        return new AllureAttachment();
    }

    /**
     * Create an instance of {@link Issue }
     * 
     */
    public Issue createIssue() {
        return new Issue();
    }

    /**
     * Create an instance of {@link AllureTestSuiteInfo }
     * 
     */
    public AllureTestSuiteInfo createAllureTestSuiteInfo() {
        return new AllureTestSuiteInfo();
    }

    /**
     * Create an instance of {@link DefectItem }
     * 
     */
    public DefectItem createDefectItem() {
        return new DefectItem();
    }

    /**
     * Create an instance of {@link Time }
     * 
     */
    public Time createTime() {
        return new Time();
    }

    /**
     * Create an instance of {@link Thread }
     * 
     */
    public Thread createThread() {
        return new Thread();
    }

    /**
     * Create an instance of {@link Host }
     * 
     */
    public Host createHost() {
        return new Host();
    }

    /**
     * Create an instance of {@link AllureTestCaseInfo }
     * 
     */
    public AllureTestCaseInfo createAllureTestCaseInfo() {
        return new AllureTestCaseInfo();
    }

    /**
     * Create an instance of {@link TestId }
     * 
     */
    public TestId createTestId() {
        return new TestId();
    }

    /**
     * Create an instance of {@link AllureStep }
     * 
     */
    public AllureStep createAllureStep() {
        return new AllureStep();
    }

    /**
     * Create an instance of {@link AllureDefect }
     * 
     */
    public AllureDefect createAllureDefect() {
        return new AllureDefect();
    }

    /**
     * Create an instance of {@link Statistic }
     * 
     */
    public Statistic createStatistic() {
        return new Statistic();
    }

    /**
     * Create an instance of {@link AllureReportInfo }
     * 
     */
    public AllureReportInfo createAllureReportInfo() {
        return new AllureReportInfo();
    }

    /**
     * Create an instance of {@link AllureStory }
     * 
     */
    public AllureStory createAllureStory() {
        return new AllureStory();
    }

    /**
     * Create an instance of {@link AllureFeature }
     * 
     */
    public AllureFeature createAllureFeature() {
        return new AllureFeature();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestSuite }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-suite")
    public JAXBElement<AllureTestSuite> createAllureTestSuite(AllureTestSuite value) {
        return new JAXBElement<AllureTestSuite>(_AllureTestSuite_QNAME, AllureTestSuite.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestCase }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-case")
    public JAXBElement<AllureTestCase> createAllureTestCase(AllureTestCase value) {
        return new JAXBElement<AllureTestCase>(_AllureTestCase_QNAME, AllureTestCase.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestCasePack }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-case-pack")
    public JAXBElement<AllureTestCasePack> createAllureTestCasePack(AllureTestCasePack value) {
        return new JAXBElement<AllureTestCasePack>(_AllureTestCasePack_QNAME, AllureTestCasePack.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureDefects }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-defects")
    public JAXBElement<AllureDefects> createAllureDefects(AllureDefects value) {
        return new JAXBElement<AllureDefects>(_AllureDefects_QNAME, AllureDefects.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTestRun }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-test-run")
    public JAXBElement<AllureTestRun> createAllureTestRun(AllureTestRun value) {
        return new JAXBElement<AllureTestRun>(_AllureTestRun_QNAME, AllureTestRun.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureTimeline }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-timeline")
    public JAXBElement<AllureTimeline> createAllureTimeline(AllureTimeline value) {
        return new JAXBElement<AllureTimeline>(_AllureTimeline_QNAME, AllureTimeline.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ListFiles }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "list-files")
    public JAXBElement<ListFiles> createListFiles(ListFiles value) {
        return new JAXBElement<ListFiles>(_ListFiles_QNAME, ListFiles.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureXUnit }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-x-unit")
    public JAXBElement<AllureXUnit> createAllureXUnit(AllureXUnit value) {
        return new JAXBElement<AllureXUnit>(_AllureXUnit_QNAME, AllureXUnit.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureGraph }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-graph")
    public JAXBElement<AllureGraph> createAllureGraph(AllureGraph value) {
        return new JAXBElement<AllureGraph>(_AllureGraph_QNAME, AllureGraph.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AllureBehavior }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "urn:data.allure.qatools.yandex.ru", name = "allure-behavior")
    public JAXBElement<AllureBehavior> createAllureBehavior(AllureBehavior value) {
        return new JAXBElement<AllureBehavior>(_AllureBehavior_QNAME, AllureBehavior.class, null, value);
    }

}
